
## CATO-CLI - mutation.sandbox.uploadFile:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sandbox.uploadFile) for documentation on this operation.

### Usage for mutation.sandbox.uploadFile:

`catocli mutation sandbox uploadFile -h`

`catocli mutation sandbox uploadFile <json>`

`catocli mutation sandbox uploadFile "$(cat < mutation.sandbox.uploadFile.json)"`

`catocli mutation sandbox uploadFile '{"uploadFileInput":{"fileName":"string"}}'`


#### Operation Arguments for mutation.sandbox.uploadFile ####

`accountId` [ID] - (required) N/A    
`uploadFileInput` [UploadFileInput] - (required) N/A    
